@@ -4,14 +4,12 @@ use strict;
 use warnings;
 use v5.30;
 
-use PDK::Device::H3c;
 use PDK::Device::Cisco;
-use PDK::Concern::Netdisco::H3c;
 use PDK::Concern::Netdisco::Cisco;
 use Data::Dumper;
 use Data::Printer;
 
 my $ip = '192.168.10.101';
-my $d  = PDK::Device::Cisco->new(host => $ip);
+my $d = PDK::Device::Cisco->new(host => $ip);
 my $nd = PDK::Concern::Netdisco::Cisco->new(device => $d);
-say Dumper $nd->explore_topology;
+say Dumper $nd->explore_topology;
\ No newline at end of file
